@@ -2,8 +2,7 @@
 import wsgi
 
 
-class NotFound(Exception):
-    pass
+class HttpError(Exception): pass
 
 class BasicAuth(Exception):
     def __init__(self):
