@@ -11,8 +11,9 @@ from Cookie import SimpleCookie
 from util import cached_property, make_traceback, obj_from_str, list_obj_from_str
 from config import cfg
 from exceptions import HttpError, BasicAuth
-from routing import auto_routing, add_apps, url4
+from routing import add_apps, url4
 from multidict import MultiDict, HeaderDict
+from static import static_url
 
 
 class Request(object):
@@ -28,7 +29,7 @@ class Request(object):
 
     @cached_property
     def context(self):
-        res = {'rq': self, 'url4': url4, 'cfg': cfg}
+        res = {'rq': self, 'url4': url4, 'cfg': cfg, 'static_url': static_url}
         for func in cfg.CONTEXT_PROCESSORS:
             res.update(func(self))
         return res
